      SUBROUTINE GUKINE
*.
*...GUKINE   Generate kinematics
*.
*. SEQUENCE  : GCFLAG GCKINE GCONST RCREP  XECGEO XECINT AIST
*. CALLS     : GPRINT GRNDM  GSKINE GSVERT REPORT USKINE HRNDM PI0SIM
*. CALLED    : GTRIG
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.25
*. CREATED   : 06-May-00
*. LAST MOD  : 20-Aug-03
*.
*. Modification Log.
*. 20-Aug-03   R.Sawada        (V1.25) GSKING(0) removed in pi0-<2gamma
*.                             event mode.
*. 20-Aug-03   K.Ozone         (V1.24) Combined COSMON, ALPHON, and
*.                             PI0ON into RUNMODE.
*.                             'IKINE=-1' in pi0 mode was moved to
*.                             uginit.F.
*. 20-Aug-03   K.Ozone         (V1.23) GSVERT was called three times in
*.                             normal single event mode.
*. 12-Aug-03   R.Sawada        (V1.22) Added pi0 mode(PI0ON).
*. 19-Aug-03   K.Ozone         (V1.21) Modified the number of randum
*.                             number in theta componemt calculation,
*.                             that is, GRNDM(RNDM,1) -> GRNDM(RNDM,2).
*. 09-Jun-03   K.Ozone         (V1.20) DSTSW(6)=5 -> COSMON,
*.                             DSTSW(6)=6 -> ALPHON.
*.                             Simplified alpha mode code.
*. 05-Jun-03   K.Ozone         (V1.19) Removed cmpedg.inc.
*. 04-Jun-03   K.Ozone         (V1.18) Changed NTRI in cosmic-ray/alpha
*.                             mode.
*.                             At random --> in order.
*. 22-Jan-03   R.Sawada        (V1.17) Added cosmic-ray mode and alpha
*.                             mode.
*. 15-Jul-02   K.Ozone         (V1.16) Added ZIN.
*. 04-Jul-02   K.Ozone         (V1.15) Simplified KINE. Mode < -112
*.                             in KINE is not used any longer.
*.                             Gaussian dist. and user-defined
*.                             histogram are available in x, y, z,
*.                             angles, and momentum.
*.                             Kinematics become more flexible.
*.                             PKINE usage changed. MOMTM added.
*.                             Newly DSTHID and DSTSW adapted.
*. 31-Mar-02   K.Ozone         (V1.14) Added inclusion of aistcg.inc
*. 21-Mar-02   K.Ozone         (V1.13) Improved the energy distribution
*.                             of backward scat'd Compton.
*.                             Removed declare.inc inclusion.
*.                             Modified about -3000<IKINE<-2000.
*. 08-Mar-02   K.Ozone         (V1.12) Adapted BSCON switch
*. 23-Feb-02   K.Ozone         (V1.11) Support for random distribution
*.                             in z direction.(ptype on -2000's)
*.                             Good for cosmic ray simuration.
*. 02-Aug-01   K.Ozone         (V1.10) Support for Comptom scat'd gamma
*.                             distributions
*. 01-Feb-01   T.Mashimo       (V1.10) Support for uniform distributions
*.                             for x and y incident positions.
*. 06-May-00   T.Mashimo       (V1.00) 1st version.
*.
*.**********************************************************************
*
#include "geant321/gconst.inc"
#include "geant321/gcflag.inc"
#include "geant321/gckine.inc"
#include "xecgeo.inc"
#include "xecint.inc"
#include "ntuple.inc"
#include "rcrep.inc"
#include "aistcg.inc"
#include "lpflag.inc"
*
      LOGICAL INIT
      SAVE    INIT
*
      INTEGER NVERT, NT, I, NTRI
      REAL    RNDM(3)
      REAL    VERTEX(3), PABS, PLAB(3), VRTX(2),
     +        COSTH1, COSTH2, COSTH, SINTH, PHI
      REAL    TTRIG(3), BTRIG(3), TLENGTH, TZPOS(3)
*
      DATA TZPOS / 3., 19.8, 38.4 / ! 1: front, 2:middle, 3:back
*
      DATA INIT   / .FALSE. /
      TTRIG(2) = 120.
      BTRIG(2) = -60.
*
      IF (.NOT. INIT) THEN
         INIT = .TRUE.
      END IF
*
      IF (IKINE .GT. 0 .OR. IKINE .LT. -112) THEN
*
*--      If the 1st parameter of the KINE FFREAD data card is 0,
*--      the user is responsible for generating kinematics
*
         GOTO 500
*
      ELSE
*
         IF (RUNMODE .EQ. 1) THEN ! cosmic ray mode
            NTRI = MOD(EVENT, 3)+1 ! 1: front, 2:middle, 3:back
            CALL GRNDM(RNDM,2)
            TTRIG(1) = -5.0 + RNDM(1)*10
            BTRIG(1) = 1.25 + RNDM(2)*10
            CALL GRNDM(RNDM,2)
            TTRIG(3) = TZPOS(NTRI) + RNDM(1)*10
            BTRIG(3) = TZPOS(NTRI) + RNDM(2)*10
            TLENGTH = SQRT(
     +           (TTRIG(1) - BTRIG(1))**2
     +           +(TTRIG(2) - BTRIG(2))**2
     +           +(TTRIG(3) - BTRIG(3))**2
     +           )
            
            VERTEX(1) = (30. - TTRIG(2))*(TTRIG(1) - BTRIG(1))/(TTRIG(2) 
     +           - BTRIG(2)) + TTRIG(1)
            VERTEX(2) = 30.
            VERTEX(3) = (30. - TTRIG(2))*(TTRIG(3) - BTRIG(3))/(TTRIG(2) 
     +           - BTRIG(2)) + TTRIG(3)
            
            CALL GSVERT(VERTEX, 0, 0, 0, 0, NVERT)
            IF (NVERT .LE. 0) THEN
               WRITE(CHREP, '(''GSVERT: NVERT = '', I10)') NVERT
               CALL REPORT('GUKINE', 1, 'ERROR')
            END IF
            
            PLAB(1) = MOMTM(1) * (BTRIG(1) - TTRIG(1))/TLENGTH
            PLAB(2) = MOMTM(1) * (BTRIG(2) - TTRIG(2))/TLENGTH
            PLAB(3) = MOMTM(1) * (BTRIG(3) - TTRIG(3))/TLENGTH
*
         ELSE IF (RUNMODE .EQ. 2) THEN ! alpha particle mode
            NTRI = MOD(EVENT, 4)
            CALL GRNDM(RNDM, 3)
            VRTX(1) = 0.1*RNDM(1) - 0.05
            VRTX(2) = PALPHA + 0.0002*RNDM(2) ! add +0.0002 if needed.
            VERTEX(3) = 12.4 - 0.05 + 0.1*RNDM(3)
            CALL GRNDM(RNDM, 2)
            PHI = 2. * PI * RNDM(2)
            SINTH = SQRT(1. - RNDM(1)*RNDM(1))
            PLAB(3) = SIN(PHI) * SINTH
            IF (NTRI .EQ. 0) THEN      !top
               VERTEX(1) = VRTX(1)
               VERTEX(2) = VRTX(2)
               PLAB(1) = COS(PHI) * SINTH
               PLAB(2) = - RNDM(1) 
            ELSE IF (NTRI .EQ. 1) THEN !bottom
               VERTEX(1) = VRTX(1)
               VERTEX(2) = -VRTX(2)
               PLAB(1) = COS(PHI) * SINTH
               PLAB(2) = RNDM(1)
            ELSE IF (NTRI .EQ. 2) THEN !left
               VERTEX(1) = VRTX(2)
               VERTEX(2) = VRTX(1)
               PLAB(1) = - RNDM(1) 
               PLAB(2) = COS(PHI) * SINTH
            ELSE IF (NTRI .EQ. 3) THEN !right
               VERTEX(1) = -VRTX(2)
               VERTEX(2) =  VRTX(1)
               PLAB(1) =  RNDM(1) 
               PLAB(2) = COS(PHI) * SINTH
            END IF
            CALL GSVERT(VERTEX, 0, 0, 0, 0, NVERT)
            IF (NVERT .LE. 0) THEN
               WRITE(CHREP, '(''GSVERT: NVERT = '', I10)') NVERT
               CALL REPORT('GUKINE', 1, 'ERROR')
            END IF
            
            PLAB(1)= MOMTM(1) * PLAB(1)
            PLAB(2)= MOMTM(1) * PLAB(2)
            PLAB(3)= MOMTM(1) * PLAB(3)
*
         ELSE IF (RUNMODE .EQ. 3) THEN ! pi0->2gamma mode
            CALL PI0SIM
            DO I=1,3
               PLAB(I)=PPIZ(I)
            END DO
            CALL GSKINE(PLAB, -IKINE, NVERT, 0, 0, NT)
            DO I=1,3
               PLAB(I)=PPIZ(I+3)
            END DO
*
         ELSE
*
*--      A single particle is to be generated.
*--      Its particle code is -IKINE.
*

*
*--      calculate impinging points
*
            DO I=1,3
               CALL GRNDM(RNDM, 2)
               IF (DSTSW(I) .EQ. 1) THEN ! pos-dist. obeys given histogram
                  VERTEX(I) = HRNDM1(DSTHID(I))
               ELSE IF (DSTSW(I) .EQ. 2) THEN ! Gaussian dist.
                  VERTEX(I)=SQRT(-2.*LOG(RNDM(1)))*COS(2.*PI*RNDM(2))*
     +                 PKINE(I*2) + PKINE(I*2-1)
               ELSE             ! flat dist.
                  VERTEX(I) = PKINE(I*2-1)
     +                 +RNDM(1)*(PKINE(I*2)-PKINE(I*2-1))
               END IF
            END DO
            CALL GSVERT(VERTEX, 0, 0, 0, 0, NVERT)
            IF (NVERT .LE. 0) THEN
               WRITE(CHREP, '(''GSVERT: NVERT = '', I10)') NVERT
               CALL REPORT('GUKINE', 1, 'ERROR')
            END IF
*
*--      calculate monemtum
*
            CALL GRNDM(RNDM, 2)
            IF ((DSTSW(6) .EQ. 1) .OR. (DSTSW(6) .EQ. 3)) THEN ! given histogram
               PABS = HRNDM1(DSTHID(6))
            ELSE IF (DSTSW(6) .EQ. 2) THEN ! Gaussian dist.
               PABS=SQRT(-2.*LOG(RNDM(1)))*COS(2.*PI*RNDM(2))*
     +                   MOMTM(2) + MOMTM(1)
            ELSE                ! flat energy dist.
               PABS = MOMTM(1)+RNDM(1)*(MOMTM(2)-MOMTM(1))
            END IF
            PABS = PABS*0.001   ! MeV to GeV
*
*--      calculate phi component of momentum
*
            CALL GRNDM(RNDM, 2)
            IF (DSTSW(5) .EQ. 1) THEN ! phi dist. obeys given historgam
               PHI = DEGRAD*HRNDM1(DSTHID(5))
            ELSE IF (DSTSW(5) .EQ. 2) THEN ! Gaussian dist.
               PHI = DEGRAD*(SQRT(-2.*LOG(RNDM(1)))*COS(2.*PI*RNDM(2))*
     +                       PKINE(10) + PKINE(9))
            ELSE                ! flat dist.
               PHI = DEGRAD*(PKINE(9) + RNDM(1)*(PKINE(10) - PKINE(9)))
            END IF
*--      calculate theta component of momentum         
            CALL GRNDM(RNDM, 2)
            IF (DSTSW(4) .EQ. 1) THEN ! theta dist. obeys given histogram
               PABS = HRNDM1(DSTHID(4))
            ELSE IF (DSTSW(4) .EQ. 2) THEN ! Gaussian dist. (correct???)
               COSTH1 = COS(PKINE(7)*DEGRAD)
               COSTH2 = ABS(COS((PKINE(7)+PKINE(8))*DEGRAD)-COSTH1)
               COSTH = SQRT(-2.*LOG(RNDM(1)))*COS(2.*PI*RNDM(2))*
     +                      COSTH2 + COSTH1
            ELSE                ! flat dist.
               COSTH1 = COS(PKINE(7)*DEGRAD)
               COSTH2 = COS(PKINE(8)*DEGRAD)
               COSTH = COSTH2 + RNDM(1)*( COSTH1 - COSTH2 )
            END IF
            IF (ABS(COSTH) .GT. 1.0) COSTH = SIGN(1.0, COSTH)
            SINTH = SQRT(1. - COSTH*COSTH)
*
*--      calculate 3-momentum
*
            PLAB(1) = PABS * SINTH * COS(PHI)
            PLAB(2) = PABS * SINTH * SIN(PHI)
            PLAB(3) = PABS * COSTH
         END IF
*
         CALL GSKINE(PLAB, -IKINE, NVERT, 0, 0, NT)
         IF (NT .LE. 0) THEN
            WRITE(CHREP, '(''GSKINE: NT = '', I10)') NT
            CALL REPORT('GUKINE', 2, 'ERROR')
         END IF
*
      END IF
*     
 500  CONTINUE
*     
 900  CONTINUE
*
*--   Fill ntuple variables
*
      EVENT = EVENT + 1
      EIN   = PABS
      XIN   = VERTEX(1)
      YIN   = VERTEX(2)
      ZIN   = VERTEX(3)
      THIN  = ACOS(COSTH)
*
*--   Initialize variables in /XECINT/
*
      NINTER = 0
      DO 910 I = 1, 3
         X1INTR(I) = 1.E+15
         X1CONV(I) = 1.E+15
 910  CONTINUE
      DEXESM = 0.0
      DEREST = 0.0
      NDEXE  = 0
      DEXESC = 0.0
*
*-- Call user routine
*
      CALL USKINE
*
*-- Print kinematics
*
      IF (IDEBUG .NE. 0) THEN
         CALL GPRINT('VERT', 0)
         CALL GPRINT('KINE', 0)
      END IF
*
  999 CONTINUE
      RETURN
      END
