      SUBROUTINE XEGPMT
*.
*...XEGPMT   Define geometry of the PMT for the liq. Xe photon detector
*.
*. SEQUENCE  : GCCUTS GCFLAG GCLIST GCONST
*.           : GMMATM RCREP
*. CALLS     : GSATT  GSPOS  GSVOLU REPORT
*. CALLED    : GMGEOM
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.05
*. CREATED   : 17-Mar-00
*. LAST MOD  : 09-Jul-03
*.
*. Modification Log.
*. 09-Jul-03   R.Sawada        (V1.05) Put Tip-tube Base,and Filler in
*.                             XPMT. Added XPPH. Introduced ZPOSBS and
*.                             ZPOSPH.
*. 21-Apr-03   R.Sawada        (V1.04) Modified geometry and Added
*.                             fillers.
*. 05-Jul-02   K.Ozone         (V1.03) Removed QEFF initialization.
*.                             It was moved to lpiffr.F.
*. 23-Feb-02   K.Ozone         (V1.02) QE*CE was changed 0.079 to 0.05.
*. 16-May-00   T.Mashimo       (V1.01) SPxxxx -> VPxxxx.
*. 17-Mar-00   T.Mashimo       (V1.00) First version.
*.
*.**********************************************************************
*.
*.   The z-axis of the local coordinate system runs along the axis of
*. the PMT.  The +z is on the side of the quartz glass window.
*.   The volume for the quartz glass window 'XPWD' is not made a
*. daughter of the volume 'XPMT'.  The caller should put 'XPMT' and
*. 'XPWD' at the same level in the volume tree.  This is to facilitate
*. the tracking of scintillation photons and also to allow putting LXe
*. surrounding the XPWD.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "geant321/gconst.inc"
#include "geant321/gccuts.inc"
#include "geant321/gcflag.inc"
#include "geant321/gclist.inc"
#include "rcrep.inc"
#include "gmmatm.inc"
#include "xecpmt.inc"
#include "lpflag.inc"
*
      INTEGER IVOL, I
      REAL    ZPXPDY
      REAL    ZPXPFL
      REAL    ZPOSBS
      REAL    ZPOSPH

*
*-- Initialization
*
      DATA VPXPWD / 0.000, 2.525, 0.15   /
      DATA VPXPMT / 0.000, 2.780, 2.0    / 
      DATA VPXPDY / 0.000, 2.550, 0.0063 /
      DATA VPXPBS / 0.500, 2.240, 0.1    /
      VPXPPH(1) = 2.4
      VPXPPH(2) = VPXPMT(2)
      VPXPPH(3) = VPXPMT(3)-1.45
      VPXPFL(1) = 0.0
      VPXPFL(2) = VPXPMT(2)
      VPXPFL(3) = VPXPMT(3) - 1.15
      VPXPSS(2) = VPXPMT(2)
      VPXPSS(1) = VPXPSS(2) - 0.0160
      VPXPSS(3) = 1.45
      ZSXPDY = VPXPMT(3) - 0.155
      ZGXPDY = 0.080
      ZPXPGL = VPXPMT(3) - 2.1
      ZPOSBS = VPXPMT(3) - 2.9 - VPXPBS(3)
      ZPOSPH = -VPXPMT(3) + VPXPPH(3)
      ZPXPFL = -VPXPMT(3) + VPXPFL(3)
*
      DATA (VPXPGL(I), I=1, 33) /
     +      0.0,  360., 10.,  !  1- 4  phi, dphi, nz
     +      0.0,   1.0, 0.0,  !  5- 7  z1(rmin1, rmax1, z1)
     +     -0.05,  0.5, 0.0,  !  8-10  z2
     +     -0.2,   0.0, 0.0,  ! 11-13  z3
     +     -0.25,  0.0, 0.5,  ! 14-16  z4
     +     -0.5,   0.0, 0.3,  ! 17-19  z5
     +     -0.8,   0.0, 0.3,  ! 20-22  z6
     +     -1.1,   0.0, 0.3,  ! 23-25  z7
     +     -1.25,  0.0, 0.27, ! 26-28  z8
     +     -1.4,   0.0, 0.05, ! 29-31  z9
     +     -1.5,   0.0, 0.0 / ! 32-33  z10
      VPXPGL(6)  = VPXPSS(2) - 0.016
      VPXPGL(9)  = VPXPGL(6)
      VPXPGL(12) = VPXPGL(6)
*
      RCATH  = 4.5/2.
*
*-- Quartz glass window
*
      CALL GSVOLU('XPWD', 'TUBE', TMXPWD, VPXPWD, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPWD:'', I8)') IVOL
         CALL REPORT('XEGPMT', 1, 'ERROR')
      END IF
      CALL GSATT('XPWD', 'SEEN', 1)
*
*-- Mother volume
*
      CALL GSVOLU('XPMT', 'TUBE', TMVACU, VPXPMT, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPMT:'', I8)') IVOL
         CALL REPORT('XEGPMT', 2, 'ERROR')
      END IF
      CALL GSATT('XPMT', 'SEEN', 0)
*
*-- SUS tube
*
      CALL GSVOLU('XPSS', 'TUBE', TMXPSS, VPXPSS, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPWD:'', I8)') IVOL
         CALL REPORT('XEGPMT', 3, 'ERROR')
      END IF
      CALL GSATT('XPSS', 'SEEN', 1)
      ZPXPSS = VPXPMT(3) - VPXPSS(3)
      CALL GSPOS('XPSS', 1, 'XPMT', 0., 0., ZPXPSS, 0, 'ONLY')
*
*-- Dynodes
*
      CALL GSVOLU('XPDY', 'TUBE', TMXPDY, VPXPDY, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPDY:'', I8)') IVOL
         CALL REPORT('XEGPMT', 4, 'ERROR')
      END IF
      CALL GSATT('XPDY', 'SEEN', 1)
      ZPXPDY = ZSXPDY
      DO 100 I = 1, 13
         CALL GSPOS('XPDY', I, 'XPMT', 0., 0., ZPXPDY, 0, 'ONLY')
         ZPXPDY = ZPXPDY - ZGXPDY
 100  CONTINUE
*
*-- Stem (glass)
*
      CALL GSVOLU('XPGL', 'PCON', TMXPGL, VPXPGL, 33, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPGL:'', I8)') IVOL
         CALL REPORT('XEGPMT', 5, 'ERROR')
      END IF
      CALL GSATT('XPGL', 'SEEN', 1)
      CALL GSPOS('XPGL', 1, 'XPMT', 0., 0., ZPXPGL, 0, 'ONLY')
*
*-- Base (G10)
*
      CALL GSVOLU('XPBS', 'TUBE', TMXPBS, VPXPBS, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPWD:'', I8)') IVOL
         CALL REPORT('XEGPMT', 6, 'ERROR')
      END IF
      CALL GSATT('XPBS', 'SEEN', 1)
      CALL GSPOS('XPBS', 1, 'XPMT',
     +     0, 0, ZPOSBS, 0, 'ONLY')

*
*-- Holder
*
      CALL GSVOLU('XPPH', 'TUBE', TMXPBS, VPXPPH, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPPH:'', I8)') IVOL
         CALL REPORT('XEGPMT', 6, 'ERROR')
      END IF
      CALL GSATT('XPPH', 'SEEN', 1)
      CALL GSPOS('XPPH', 1, 'XPMT',
     +     0, 0, ZPOSPH, 0, 'ONLY')
*
*-- Filler or Xenon
*
      IF(FILLON .EQ. 1) THEN
         CALL GSVOLU('XPFL', 'TUBE', TMXFIL, VPXPFL, 3, IVOL)
      ELSE 
         CALL GSVOLU('XPFL', 'TUBE', TMXELQ, VPXPFL, 3, IVOL)
      END IF
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPFL:'', I8)') IVOL
         CALL REPORT('XEGPMT', 6, 'ERROR')
      END IF
      CALL GSATT('XPFL', 'SEEN', 1)
      CALL GSPOS('XPFL', 1, 'XPMT', 0., 0., ZPXPFL, 0, 'MANY')
*
  999 CONTINUE
      RETURN
      END
