      SUBROUTINE XSTRAK(DEPOX)
*.
*...XSTRAK   Genereate and transport scintillation light in liq. Xe
*.
*. INPUT     : DEPOX(1-3)  position of energy deposit (x,y,z)
*. INPUT     : DEPOX(4)    deposited energy in GeV
*.
*. SEQUENCE  : GCONST
*.           : RCREP  XECGEO XECPMT XECSCI
*. CALLS     : REPORT XSPOIS XSRNDM XSHITP
*. CALLED    : GUOUT
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.18
*. CREATED   : 11-Apr-00
*. LAST MOD  : 18-Aug-03
*.
*. Modification Log.
*. 18-Aug-03   S.Yamada        (V1.18) Moved the function of (V1.17) to
*.                             xsrefidx.F as a FUNCTION.
*. 11-Jul-03   R.Sawada        (V1.17) Enabled LXe and quartz refractive
*.                             index according to a wave-length function.
*. 11-Jul-03   R.Sawada        (V1.16) Prepared for LXe refractive index
*.                             distribution. But not implemented yet.
*. 05-Jun-03   R.Sawada        (V1.15) Introduced LTIME and changed FILL
*.                             to LEVEL
*. 24-May-03   R.Sawada        (V1.14) Fixed a bug at quartz absorption.
*. 14-Mar-03   R.Sawada        (V1.13) Added arrival time storation.
*. 04-Feb-03   R.Sawada        (V1.12) Enabled to scintillate outside
*.                             WALL(I)
*. 22-Jan-03   R.Sawada        (V1.11) Modified quartz absorption.
*.                             TRANS is value against 2mmm quartz,
*.                             but actuallly PMT quartz window is 2.5mm.
*. 24-Jul-02   K.Ozone         (V1.10) Changed CTHETA in quartz
*.                             refrection loop to CRAGXQ, while in Xe
*.                             surface loop CTHETA to CRAGXV.
*. 20-Jul-02   K.Ozone         (V1.09) TRANS array was multipled by
*.                             0.01, that is, changed percentage to
*.                             ratio. It was a big mistake.
*. 06-Jul-02   K.Ozone         (V1.08) Fixed a fatal bug which occurs
*.                             infinty loop between top face and Xe
*.                             surface because photon position vector X
*.                             are not set to hitted point in quartz
*.                             reflection loop.
*.                             Improved absorption loop to introduce
*.                             wave length.
*.                             Changed XDEPO to DEPOX in order to
*.                             avoid confusion with XDEPO in ntuple.
*.                             Added wavelength-depended Rayleigh
*.                             scattering. (LRAYL = 3)
*.                             Changed QEFF to PMTQEF.
*. 02-Jul-02   K.Ozone         (V1.07) QABSON switch for V1.06
*. 01-Jul-02   R.Sawada        (V1.06) Absorption on PMT quartz window
*. 16-Mar-02   K.Ozone         (V1.05) Modified to speed up in loops
*. 21-Feb-02   R.Sawada        (V1.04) Support for photon reflection on
*.                             quartz window
*. 05-Sep-01   W.Ootani        (V1.03) Take into account of liquid xenon
*.                             surface.
*.                             But filled with vacuum instead of Gas Xe
*.                             over liquid Xe surface.
*. 30-Jan-01   T.Mashimo       (V1.02) Fix two bugs;
*.                             (1) When I modified scsim.F, I forgot
*.                             to remove some debris of T. Mori's code;
*.                             simulation of light absorption should
*.                             have been wrong.  (Hopefully nobody has
*.                             ever switched on light absorption.)
*.                             (2) For "XESCRAYL 2", the photon position
*.                             was not advanced when scattering takes
*.                             place.
*. 18-Jan-01   T.Mashimo       (V1.01) Support for "XESCRAYL 2".
*. 11-Apr-00   T.Mashimo       (V1.00) 1st version based on T. Mori's
*.                             SCSIM.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "geant321/gconst.inc"
#include "xecgeo.inc"
#include "xecpmt.inc"
#include "xecsci.inc"
#include "xecint.inc"
#include "rcrep.inc"
*
      REAL    DEPOX(5)
*
      INTEGER NPH, IPH,
     +        IWALL, IFACE, IHIT, IADDR, IERR,
     +        IW, ISCAT, I, K
      REAL    AVNPH
      REAL    X(3), RN(2), CTH, STH, CPH, SPH, V(4), XHIT(3), DIST,
     +        XABSO, XRAYL
      REAL    TH1, TH2
      REAL    CTH1, STH1, CTH2, STH2, THETA1, THETA2
      REAL    RFLCTC ! refractance of quartz
      REAL    TRNSMT ! transmittance of PMT window
      REAL    KK
      REAL    VNEW(3)
      LOGICAL ROTATE
      INTEGER DIRCT
      REAL    LTIME
      REAL    DPHAI,DSINTH
      INTEGER IAXIS(2,3), IXYZ(2)
      REAL    OFFVAL
*
      REAL    OFFPMT(2), R2
      REAL    WLEN
      DATA    IAXIS / 2,3, 3,1, 1,2 /
*
      REAL     XSWVLN, QTRANS
*
*-- Determine number of scintillation photons to be generated
*
      IF (DEPOX(1) .GT. WALL(1) .AND.
     +     DEPOX(1) .LT. WALL(2) .AND.
     +     DEPOX(2) .GT. WALL(3) .AND.
     +     DEPOX(2) .LT. WALL(4) .AND.
     +     DEPOX(3) .GT. WALL(5) .AND.
     +     DEPOX(3) .LT. WALL(6)) THEN
         AVNPH = DEPOX(4)/ESCINT*PMTQEF ! == # of photo-electrons
      ELSE
         IF (DEPOX(1) .LE. WALL(1)) THEN
            IWALL = 1
         ELSE IF(DEPOX(1) .GE. WALL(2)) THEN
            IWALL = 1
         ELSE IF(DEPOX(2) .LE. WALL(3)) THEN
            IWALL = 2
         ELSE IF(DEPOX(2) .GE. WALL(4)) THEN
            IWALL = 2
         ELSE IF(DEPOX(3) .LE. WALL(5)) THEN
            IWALL = 3
         ELSE IF(DEPOX(3) .GE. WALL(6)) THEN
            IWALL = 3
         END IF
         DO 30 K = 1, 2         !e.g. for IWALL=z : 
            I = IAXIS(K, IWALL) !       I=x,y (for k=1,2)
            OFFVAL = DEPOX(I) - WALL(2*I-1)  ! OFFVAL = xhit - xwall(-)
            IXYZ(K) = INT(OFFVAL/PMTINT) + 1
            OFFPMT(K) = AMOD(OFFVAL, PMTINT) ! hit position inside 'PMT unit'
 30      CONTINUE
         R2 = (OFFPMT(1) - PMTINT/2.)**2 + (OFFPMT(2) - PMTINT/2.)**2
         IF (R2 .GT. RCATH*RCATH) THEN ! outside PMT; RCATH=radius
            AVNPH = DEPOX(4)/ESCINT*PMTQEF ! == # of photo-electrons
         ELSE !inside PMT
            GOTO 999
         END IF
      END IF
*
*-- DESTEP > keV by GUSTEP
*
      PEGEN = PEGEN + AVNPH
      IF (IPOISN .EQ. 1) THEN
         CALL XSPOIS(AVNPH, NPH, 1)
      ELSE
         NPH = NINT(AVNPH)
      END IF
      NPEGEN = NPEGEN + NPH
*
      DO 500 IPH = 1, NPH
*
         RFLG = 1 ! initial photons are in xenon
*
         X(1) = DEPOX(1)
         X(2) = DEPOX(2)
         X(3) = DEPOX(3)
*
         LTIME = DEPOX(5)
*
         WLEN = XSWVLN()
         IF(XENDST .EQ. 1) THEN
            CALL XSREFIDX(WLEN)
            VLIGHT = CLIGHT/RFRIDX
            QRFIDX = EXP(-0.01354 * WLEN + 0.1869) + 1.464
            IF(QRFIDX .LE. RFRIDX) THEN
               CRAGXQ = ASIN(QRFIDX/RFRIDX)
            ELSE
               CRAGXQ = ASIN(1.)
            END IF
         ENDIF
*
 200     CONTINUE
*
         CALL XSRNDM(RN, 2)
         CTH = 2.*RN(1) - 1.
         IF (ABS(CTH) .GE. 1.) THEN
            CTH = SIGN(1., CTH)
            STH = 0.
         ELSE
            STH = SQRT(1.0 - CTH**2)
         END IF
         V(1) = STH*COS(TWOPI*RN(2))  ! photon direction
         V(2) = STH*SIN(TWOPI*RN(2))  !
         V(3) = CTH                   !
         V(4) = VLIGHT                !
*
 300     CONTINUE
*
         IF (((X(1) .LE. WALL(1)) .AND. (V(1) .LT. 0.)) .OR.
     +        ((X(1) .GE. WALL(2)) .AND. (V(1) .GT. 0.)) .OR.
     +        ((X(2) .LE. WALL(3)) .AND. (V(2) .LT. 0.)) .OR.
     +        ((X(2) .GE. WALL(4)) .AND. (V(2) .GT. 0.)) .OR.
     +        ((X(3) .LE. WALL(5)) .AND. (V(3) .LT. 0.)) .OR.
     +        ((X(3) .GE. WALL(6)) .AND. (V(3) .GT. 0.))) THEN 
            GOTO 500            !absorbed
         END IF
*
*-- Transport scintillation light to the wall
*
         CALL XSHITP(X, V, IWALL, IFACE, XHIT, DIST, IHIT, IADDR, IERR)
         IF (IERR .NE. 0) GO TO 500 ! skip if error
*
         ISCAT = 0
         XABSO = 1.E10
         XRAYL = 1.E10
         CALL XSRNDM(RN, 2)
         IF (IABSO .GE. 1) XABSO = -DABSO*ALOG(RN(1))
         IF (LRAYL .GE. 1) THEN
            XRAYL = -DRAYL*ALOG(RN(2))
            IF (LRAYL .EQ. 3) THEN
               XRAYL = XRAYL*(WLEN/175.)**4
            END IF
         END IF
*
         IF(RFLG .EQ. 1) THEN   ! if photon inside xenon
*
            IF (XRAYL .GE. XABSO) THEN
               IF (DIST .GT. XABSO) GO TO 500 ! absorbed
            ELSE
               IF (DIST .GT. XRAYL) THEN ! scattered
                  ISCAT = 1
                  IF (LRAYL .EQ. 1) THEN
                     X(1) = X(1) + XRAYL*V(1)
                     X(2) = X(2) + XRAYL*V(2)
                     X(3) = X(3) + XRAYL*V(3)
                     LTIME = LTIME + XRAYL/V(4)
                     GO TO 200
                  ELSE IF (LRAYL .GE. 2) THEN
 320                 CONTINUE
                     CALL XSRNDM(RN, 2)
                     CTH = 2.*RN(1) - 1.
                     IF (ABS(CTH) .GE. 1.) CTH = SIGN(1., CTH)
                     STH = SQRT(1.0 - CTH**2)
                     IF (RN(2) .GT. 0.5*(1.+CTH**2)) GO TO 320
*
                     CALL XSRNDM(RN, 1)
                     CPH = COS(TWOPI*RN(1))
                     SPH = SIN(TWOPI*RN(1))
                     VNEW(1) = STH*CPH
                     VNEW(2) = STH*SPH
                     VNEW(3) = CTH
                     CALL GFANG(V, CTH, STH, CPH, SPH, ROTATE)
                     IF (ROTATE) CALL GDROT(VNEW, CTH, STH, CPH, SPH)
                     X(1) = X(1) + XRAYL*V(1)
                     X(2) = X(2) + XRAYL*V(2)
                     X(3) = X(3) + XRAYL*V(3)
                     LTIME = LTIME + XRAYL/V(4)
                     CALL UCOPY(VNEW, V, 3)
                     GO TO 300
                  END IF
               END IF
            END IF
         END IF
*
*-- If it hits the photo-cathode of a PMT
*
         IF (IHIT .EQ. 1) THEN
            IW = 2*IWALL + IFACE - 2 ! wall number = 1-6
*
*--   forbid any hits from the back of PMT
*
            IF ((IW .EQ. 1 .AND. V(1) .GT. 0)
     +           .OR. (IW .EQ. 2 .AND. V(1) .LT. 0)
     +           .OR. (IW .EQ. 3 .AND. V(2) .GT. 0)
     +           .OR. (IW .EQ. 4 .AND. V(2) .LT. 0)
     +           .OR. (IW .EQ. 5 .AND. V(3) .GT. 0)
     +           .OR. (IW .EQ. 6 .AND. V(3) .LT. 0)) THEN
               GO TO 500
            END IF
*
*--- which face does the photon hit on ?
*--- 1:right, 2:left, 3:top, 4:bottom, 5:front, 6:back
*
            IF (QREFON .EQ. 1) THEN
               X(1) = XHIT(1)
               X(2) = XHIT(2)
               X(3) = XHIT(3)
               LTIME = LTIME + DIST/V(4)
               DIRCT = INT((IW-1)/2+1)
               CTH1 = ABS(V(DIRCT))
               IF (ACOS(CTH1) .GT. CRAGXQ) THEN ! total reflection
                  V(DIRCT) = -V(DIRCT)
                  GO TO 300
               ELSE
                  STH1 = SQRT(1-CTH1*CTH1)
                  STH2 = STH1*(RFRIDX/QRFIDX) ! Snell's law
                  CTH2 = SQRT(1-STH2*STH2)
                  THETA1 = ACOS(CTH1)
                  THETA2 = ACOS(CTH2)
*-- calc by Fresnel reflection (no polarization)
                  RFLCTC = ((SIN(THETA1 -THETA2)
     +                 / SIN(THETA1 + THETA2))**2
     +                 + (TAN(THETA1 - THETA2)
     +                 / TAN(THETA1 + THETA2))**2)/2.
                  CALL XSRNDM(RN, 1)
                  IF (RN(1) .LT. RFLCTC) THEN
                     V(DIRCT) = -V(DIRCT) ! normal reflection
                     GO TO 300
                  END IF
               END IF
            END IF
            IF (QABSON .EQ. 1) THEN
               IF (QREFON .EQ. 0) THEN
                  DIRCT = INT((IW-1)/2+1)
                  STH2 = SQRT(1-V(DIRCT)*V(DIRCT))*(RFRIDX/QRFIDX) ! Snell's law
                  CTH2 = SQRT(1-STH2*STH2)
               END IF
               CALL XSRNDM(RN, 1)
               TRNSMT = (QTRANS(WLEN) ** (2.5/(2.*CTH2))) ! Ryu's equation
               IF (RN(1) .GE. TRNSMT) GO TO 500 ! absorbed in quartz
            END IF
*
 330        NPEALL        = NPEALL + 1
            NPEWAL(IW)    = NPEWAL(IW) + 1
            NPEPMT(IADDR) = NPEPMT(IADDR) + 1
            IF(NPEPMT(IADDR) .LE. 20000) THEN
               ATIME(IADDR,NPEPMT(IADDR)) = LTIME
            END IF
            GO TO 500
*
*-- If it hits xenon surface
*
         ELSE IF ((IHIT .EQ. 2) .AND. (LEVEL .LT. 1.0)) THEN
            X(1) = XHIT(1)
            X(2) = XHIT(2)
            X(3) = XHIT(3)
            LTIME = LTIME + DIST/V(4)
            IF (RFLG .EQ. 1) THEN ! xenon->vacuum or xenon->xenon
               CTH1 = V(2)
               IF (ACOS(CTH1) .GT. CRAGXV) THEN ! total reflection
                  V(2) = -V(2)
                  GO TO 300
               ELSE
                  STH1 = SQRT(1-CTH1*CTH1)
                  STH2 = STH1*RFRIDX ! Snell's law
                  CTH2 = SQRT(1-STH2*STH2)
                  THETA1 = ACOS(CTH1)
                  THETA2 = ACOS(CTH2)
                  RFLCTC = ((SIN(THETA1 - THETA2)
     +                 / SIN(THETA1 + THETA2))**2
     +                 + (TAN(THETA1 - THETA2)
     +                 / TAN(THETA1 + THETA2))**2)/2.
                  CALL XSRNDM(RN, 1)
                  IF (RN(1) .LT. RFLCTC) THEN
                     V(2) = -V(2) ! normal reflection
                     GO TO 300 
                  ELSE
                     KK   = -CTH1+STH1*STH2/CTH2
                     V(1) = V(1)/SQRT(1+KK*KK+2*KK*V(2))
                     V(2) = (V(2)+KK)/SQRT(1+KK*KK+2*KK*V(2))
                     V(3) = V(3)/SQRT(1+KK*KK+2*KK*V(2))
                     RFLG = 0
                     GO TO 300
                  END IF
               END IF
            ELSE                ! vacuum->xenon
               CTH1 = V(2)
               STH1 = SQRT(1-CTH1*CTH1)
               STH2 = STH1/RFRIDX ! Snell's law
               CTH2 = SQRT(1-STH2*STH2)
               KK   = -CTH1+STH1*STH2/CTH2
               V(1) = V(1)/SQRT(1+KK*KK-2*KK*V(2))
               V(2) = (V(2)-KK)/SQRT(1+KK*KK-2*KK*V(2))
               V(3) = V(3)/SQRT(1+KK*KK-2*KK*V(2))
               RFLG = 1
               GO TO 300 
            END IF

*--   If it hits a place outside PMT  -- reflection?
         ELSE IF (IREFL .EQ. 1) THEN
            CALL XSRNDM(RN, 1)
            IF (RN(1) .LT. EREFL) THEN

               IF(IDEREFL .EQ. 0) THEN
                  V(IWALL) = -V(IWALL) ! regular reflection
               ELSE
                  CALL XSRNDM(RN, 2)
                  IF (IWALL .EQ. 1) THEN
                     V(1) = -RN(2)*(3 - 2*IFACE)
                     DPHAI = PI * (2 * RN(1))
                     DSINTH = SQRT(1. - V(1)**2)
                     V(2) = COS(DPHAI) * DSINTH
                     V(3) = SIN(DPHAI) * DSINTH
                  ELSE IF(IWALL .EQ. 2) THEN
                     V(2) = -RN(2)*(3 - 2*IFACE)
                     DPHAI = PI * (2 * RN(1))
                     DSINTH = SQRT(1. - V(2)**2)
                     V(3) = COS(DPHAI) * DSINTH
                     V(1) = SIN(DPHAI) * DSINTH
                  ELSE IF(IWALL .EQ. 3) THEN
                     V(3) = -RN(2)*(3 - 2*IFACE)
                     DPHAI = PI * (2 * RN(1))
                     DSINTH = SQRT(1. - V(3)**2)
                     V(1) = COS(DPHAI) * DSINTH
                     V(2) = SIN(DPHAI) * DSINTH
                  END IF
               END IF
               X(1) = XHIT(1)
               X(2) = XHIT(2)
               X(3) = XHIT(3)
               LTIME = LTIME + DIST/V(4)
               GO TO 300        ! reflected
            ELSE
               GO TO 500
            END IF
         END IF

 500  CONTINUE
*     
 999  CONTINUE
       RETURN
      END
